==> 0.0.1.tar.gz: lib/src/model/discord_model.dart <==
library discord_model;

// api
export 'api/discord_response.dart';
export 'api/discord_user_agent.dart';

// application
export 'application/application.dart';

// channel
export 'channel/allowed_mention_type.dart';
export 'channel/allowed_mentions.dart';
export 'channel/attachment.dart';
export 'channel/channel_mention.dart';
export 'channel/channel_type.dart';
export 'channel/channel.dart';
export 'channel/message_activity_type.dart';
export 'channel/message_activity.dart';
export 'channel/message_reference.dart';
export 'channel/message_type.dart';
export 'channel/message.dart';
export 'channel/overwrite.dart';
export 'channel/reaction.dart';
export 'channel/thread_member.dart';
export 'channel/thread_metadata.dart';
export 'channel/video_quality_mode.dart';

// channel/embed
export 'channel/embed/embed_author.dart';
export 'channel/embed/embed_field.dart';
export 'channel/embed/embed_footer.dart';
export 'channel/embed/embed_image.dart';
export 'channel/embed/embed_provider.dart';
export 'channel/embed/embed_thumbnail.dart';
export 'channel/embed/embed_type.dart';
export 'channel/embed/embed_video.dart';
export 'channel/embed/embed.dart';

// emoji
export 'emoji/emoji.dart';

// guild
export 'guild/guild_member.dart';

// interactions/application_commands
export 'interactions/application_commands/application_command_interaction_data_option.dart';
export 'interactions/application_commands/application_command_option_choice.dart';
export 'interactions/application_commands/application_command_option_type.dart';
export 'interactions/application_commands/application_command_option.dart';
export 'interactions/application_commands/application_command_permission_type.dart';
export 'interactions/application_commands/application_command_permissions.dart';
export 'interactions/application_commands/application_command_type.dart';
export 'interactions/application_commands/application_command.dart';
export 'interactions/application_commands/guild_application_command_permissions.dart';

// interactions/components
export 'interactions/components/button_style.dart';
export 'interactions/components/component_type.dart';
export 'interactions/components/component.dart';
export 'interactions/components/select_option.dart';

// interactions/interactions
export 'interactions/interactions/interaction_callback_data.dart';
export 'interactions/interactions/interaction_callback_type.dart';
export 'interactions/interactions/interaction_data.dart';
export 'interactions/interactions/interaction_response.dart';
export 'interactions/interactions/interaction_type.dart';
export 'interactions/interactions/interaction.dart';
export 'interactions/interactions/message_interaction.dart';
export 'interactions/interactions/resolved_data.dart';

// permissions
export 'permissions/role_tags.dart';
export 'permissions/role.dart';

// sticker
export 'sticker/sticker_format_type.dart';
export 'sticker/sticker_item.dart';

// teams
export 'teams/membership_state.dart';
export 'teams/team_member.dart';
export 'teams/team.dart';

// user
export 'user/premium_type.dart';
export 'user/user.dart';

==> 0.0.2.tar.gz: lib/src/model/discord_model.dart <==
library discord_model;

// api
export 'api/discord_response.dart';
export 'api/discord_user_agent.dart';

// application
export 'application/application_flag.dart';
export 'application/application.dart';

// channel
export 'channel/allowed_mention_type.dart';
export 'channel/allowed_mentions.dart';
export 'channel/attachment.dart';
export 'channel/channel_mention.dart';
export 'channel/channel_type.dart';
export 'channel/channel.dart';
export 'channel/overwrite.dart';
export 'channel/reaction.dart';
export 'channel/thread_member.dart';
export 'channel/thread_metadata.dart';
export 'channel/video_quality_mode.dart';

// channel/embed
export 'channel/embed/embed_author.dart';
export 'channel/embed/embed_field.dart';
export 'channel/embed/embed_footer.dart';
export 'channel/embed/embed_image.dart';
export 'channel/embed/embed_provider.dart';
export 'channel/embed/embed_thumbnail.dart';
export 'channel/embed/embed_type.dart';
export 'channel/embed/embed_video.dart';
export 'channel/embed/embed.dart';

// channel/message
export 'channel/message/message_activity_type.dart';
export 'channel/message/message_activity.dart';
export 'channel/message/message_flag.dart';
export 'channel/message/message_reference.dart';
export 'channel/message/message_type.dart';
export 'channel/message/message.dart';

// emoji
export 'emoji/emoji.dart';

// guild
export 'guild/guild_member.dart';

// interactions/application_commands
export 'interactions/application_commands/application_command_interaction_data_option.dart';
export 'interactions/application_commands/application_command_option_choice.dart';
export 'interactions/application_commands/application_command_option_type.dart';
export 'interactions/application_commands/application_command_option.dart';
export 'interactions/application_commands/application_command_permission_type.dart';
export 'interactions/application_commands/application_command_permissions.dart';
export 'interactions/application_commands/application_command_type.dart';
export 'interactions/application_commands/application_command.dart';
export 'interactions/application_commands/guild_application_command_permissions.dart';

// interactions/components
export 'interactions/components/button_style.dart';
export 'interactions/components/component_type.dart';
export 'interactions/components/component.dart';
export 'interactions/components/select_option.dart';

// interactions/interactions
export 'interactions/interactions/followup_message.dart';
export 'interactions/interactions/interaction_callback_data.dart';
export 'interactions/interactions/interaction_callback_type.dart';
export 'interactions/interactions/interaction_data.dart';
export 'interactions/interactions/interaction_response.dart';
export 'interactions/interactions/interaction_type.dart';
export 'interactions/interactions/interaction.dart';
export 'interactions/interactions/message_interaction.dart';
export 'interactions/interactions/resolved_data.dart';

// permissions
export 'permissions/role_tags.dart';
export 'permissions/role.dart';

// sticker
export 'sticker/sticker_format_type.dart';
export 'sticker/sticker_item.dart';

// teams
export 'teams/membership_state.dart';
export 'teams/team_member.dart';
export 'teams/team.dart';

// user
export 'user/premium_type.dart';
export 'user/user_flag.dart';
export 'user/user.dart';
